/*
 *  Pedometer - Android App
 *  Copyright (C) 2009 Levente Bagi
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This version of DistanceNotifier.java was edited by Shelby Kirn
 * no later than Wednesday, May 3, 2017.
 */
package com.example.shelby.healthquest40;


import android.content.Context;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;

/**
 * Calculates and displays the distance walked.
 * @author Levente Bagi
 */
public class DistanceNotifier implements StepListener {

    public interface Listener {
        public void valueChanged(float value);
        public void passValue();
    }
    private Listener mListener;

    float mDistance = 0; //set distance to zero

    PedometerSettings mSettings;
    //Utils mUtils;

    boolean mIsMetric;
    float mStepLength;

    public DistanceNotifier(Listener listener, PedometerSettings settings /*, Utils utils*/) {
        /*********************************************************************************
         * DistanceNotifier establishes all the components of the DistanceNotifier class *
         * that are accessible from outside the class.                                   *
         *********************************************************************************/
        mListener = listener;
        //mUtils = utils;
        mSettings = settings;
        reloadSettings();
    }
    public void setDistance(float distance) {
        /***************************************************************
         * Is called when the DistanceNotifier is first initialized in *
         * StepService.java.                                           *
         ***************************************************************/
        mDistance = distance;
        notifyListener();
    }

    public void reloadSettings() {
        /*****************************************************************
         * Reloads the step length when DistanceNotifier is initialized. *
         *****************************************************************/
        mStepLength = mSettings.getStepLength();
        notifyListener();
    }

    public void onStep() {
        /********************************************************************
         * onStep is called by the onStep function in StepDetector.java. It *
         * calculates distance based on steps.                              *
         ********************************************************************/
        Context applicationContext = MainActivity.getContextofApplication();
        SharedPreferences myPreferences = PreferenceManager.getDefaultSharedPreferences(applicationContext);
        SharedPreferences.Editor myEditor = myPreferences.edit();

        mDistance += (float)(
                     mStepLength // inches
                             / 63360.0); // inches/mile
        myEditor.putFloat("DAILY_DISTANCE", (myPreferences.getFloat("DAILY_DISTANCE", 0))+(float)(mStepLength/63360.0));

        myEditor.commit();
        //Toast.makeText(applicationContext, "distance measured", Toast.LENGTH_SHORT).show();
        notifyListener();
    }

    private void notifyListener() {
        /*****************************************************
         * Tells the listener that the distance has changed. *
         *****************************************************/
        mListener.valueChanged(mDistance);
    }

    public void passValue() {
        // Callback of StepListener - Not implemented
    }

    public void speak() {
        /******************************************************
         * DistanceNotifier will not initialize without this. *
         ******************************************************/
//        if (mSettings.shouldTellDistance()) {
//            if (mDistance >= .001f) {
//                mUtils.say(("" + (mDistance + 0.000001f)).substring(0, 4) + (mIsMetric ? " kilometers" : " miles"));
//            }
//        }
    }
}
